==> openapi-fetch-typescript-0.0.2.tgz: package/src/generateTypescriptSdk.cli.ts <==
#! /usr/bin/env node

import fs from "node:fs";
import { generateTypescriptSdk } from "./generateTypescriptSdk.js";
import path from "node:path";

const cli = async () => {
  // e.g. npx openapi-fetch-typescript https://guest163.actionschema.com/openapi.json /path/to/file [clientName]
  const [openapiUrl, pathToOutputFile, clientName] = process.argv.slice(2) as (
    | string
    | undefined
  )[];

  if (!openapiUrl) {
    console.log("Please provide an URL as the first argument");
    return;
  }

  const usage = `Usage: npx openapi-fetch-typescript [openapi-url] [output-path] [client]`;
  if (openapiUrl === "--help" || openapiUrl === "-h") {
    console.log(usage);
    return;
  }

  try {
    new URL(openapiUrl);
  } catch (e) {
    console.log(usage, "Please provide a valid URL as first argument.");
    return;
  }

  const cwd = process.cwd();
  const absolutePath = pathToOutputFile?.startsWith("/")
    ? pathToOutputFile
    : pathToOutputFile
    ? path.join(cwd, pathToOutputFile)
    : path.join(cwd, "client.ts");

  const absoluteFolderPath = path.parse(absolutePath).dir;

  if (!fs.existsSync(absoluteFolderPath)) {
    console.log("Output folder doesn't exist", absoluteFolderPath);
    return;
  }

  const { isSuccessful, message, result } = await generateTypescriptSdk({
    openapiUrl,
    clientName,
  });

  if (!isSuccessful || !result) {
    console.log({ isSuccessful, message });
    return;
  }

  fs.writeFileSync(absolutePath, result, "utf8");
  console.log("DONE writing to", absolutePath);
};

cli();

==> openapi-fetch-typescript-0.0.4.tgz: package/src/generateTypescriptSdk.cli.ts <==
#! /usr/bin/env node

import fs from "node:fs";
import { generateTypescriptSdk } from "./generateTypescriptSdk.js";
import path from "node:path";

const cli = async () => {
  // e.g. npx openapi-fetch-typescript https://guest163.actionschema.com/openapi.json /path/to/file [clientName]
  const [openapiUrl, pathToOutputFile] = process.argv.slice(2) as (
    | string
    | undefined
  )[];

  if (!openapiUrl) {
    console.log("Please provide an URL as the first argument");
    return;
  }

  const usage = `Usage: npx openapi-fetch-typescript [openapi-url] [output-path]`;
  if (openapiUrl === "--help" || openapiUrl === "-h") {
    console.log(usage);
    return;
  }

  try {
    new URL(openapiUrl);
  } catch (e) {
    console.log(usage, "Please provide a valid URL as first argument.");
    return;
  }

  const cwd = process.cwd();
  const absolutePath = pathToOutputFile?.startsWith("/")
    ? pathToOutputFile
    : pathToOutputFile
    ? path.join(cwd, pathToOutputFile)
    : path.join(cwd, "types.ts");

  const absoluteFolderPath = path.parse(absolutePath).dir;

  if (!fs.existsSync(absoluteFolderPath)) {
    console.log("Output folder doesn't exist", absoluteFolderPath);
    return;
  }

  const { isSuccessful, message, result } = await generateTypescriptSdk({
    openapiUrl,
  });

  if (!isSuccessful || !result) {
    console.log({ isSuccessful, message });
    return;
  }

  fs.writeFileSync(absolutePath, result, "utf8");
  console.log("DONE writing to", absolutePath);
};

cli();
